@@ -1,5 +1,6 @@
-## ----venneuler_failure---------------------------------------------------
-venn_fit <- venneuler::venneuler(c(A = 75, B = 50, "A&B" = 0))
+## ----venneuler_failure, fig.height=5, fig.width=5, fig.cap='venneuler plot with unwanted overlap.', dev.args=list(type='cairo-png')----
+library(venneuler,  quietly = TRUE)
+venn_fit <- venneuler(c(A = 75, B = 50, "A&B" = 0))
 par(mar = c(0, 0, 0, 0))
 plot(venn_fit)
 
@@ -13,29 +14,25 @@ fit1 <- eulerr(c("A" = 25, "B" = 5, "C" = 5,
 
 # Input as a matrix of logicals
 set.seed(1)
-mat <-
-  cbind(
+mat <- cbind(
   A = sample(c(TRUE, TRUE, FALSE), size = 50, replace = TRUE),
   B = sample(c(TRUE, FALSE), size = 50, replace = TRUE),
   C = sample(c(TRUE, FALSE, FALSE, FALSE), size = 50, replace = TRUE)
-  )
+)
 fit2 <- eulerr(mat)
 
 ## ----fit1_print----------------------------------------------------------
 fit2
 
-## ----residual_plot-------------------------------------------------------
-resid(fit2)
-
+## ----residual_plot, fig.cap='Residuals for the eulerr fit.'--------------
 # Cleveland dot plot of the residuals
 graphics::dotchart(resid(fit2))
 abline(v = 0, lty = 3)
 
-## ----stress--------------------------------------------------------------
-fit2$stress
+## ----coefs---------------------------------------------------------------
+coef(fit2)
 
-## ----eulerr_plot, fig.show='hold'----------------------------------------
-par(mar = c(0, 0, 0, 0))
+## ----eulerr_plot, fig.width=4, fig.height=4, fig.show='hold', fig.cap='eulerr plots can be modified in every possible way.', dev.args=list(type='cairo-png')----
 plot(fit2)
 
 # Change fill colors, border type (remove) and fontface.
